==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/FrameFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface FrameFluent<A extends FrameFluent<A>> extends Fluent<A> {


    public String getFuncname();
    public A withFuncname(String funcname);
    public Boolean hasFuncname();
    public A withNewFuncname(StringBuilder arg1);
    public A withNewFuncname(int[] arg1,int arg2,int arg3);
    public A withNewFuncname(char[] arg1);
    public A withNewFuncname(StringBuffer arg1);
    public A withNewFuncname(byte[] arg1,int arg2);
    public A withNewFuncname(byte[] arg1);
    public A withNewFuncname(char[] arg1,int arg2,int arg3);
    public A withNewFuncname(byte[] arg1,int arg2,int arg3);
    public A withNewFuncname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFuncname(String arg1);
    public String getParameters();
    public A withParameters(String parameters);
    public Boolean hasParameters();
    public A withNewParameters(StringBuilder arg1);
    public A withNewParameters(int[] arg1,int arg2,int arg3);
    public A withNewParameters(char[] arg1);
    public A withNewParameters(StringBuffer arg1);
    public A withNewParameters(byte[] arg1,int arg2);
    public A withNewParameters(byte[] arg1);
    public A withNewParameters(char[] arg1,int arg2,int arg3);
    public A withNewParameters(byte[] arg1,int arg2,int arg3);
    public A withNewParameters(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewParameters(String arg1);
    public String getPredicate();
    public A withPredicate(String predicate);
    public Boolean hasPredicate();
    public A withNewPredicate(StringBuilder arg1);
    public A withNewPredicate(int[] arg1,int arg2,int arg3);
    public A withNewPredicate(char[] arg1);
    public A withNewPredicate(StringBuffer arg1);
    public A withNewPredicate(byte[] arg1,int arg2);
    public A withNewPredicate(byte[] arg1);
    public A withNewPredicate(char[] arg1,int arg2,int arg3);
    public A withNewPredicate(byte[] arg1,int arg2,int arg3);
    public A withNewPredicate(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPredicate(String arg1);
}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/FrameFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface FrameFluent<A extends FrameFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getFuncname();
    public A withFuncname(String funcname);
    public Boolean hasFuncname();
    public A withNewFuncname(StringBuilder arg1);
    public A withNewFuncname(int[] arg1,int arg2,int arg3);
    public A withNewFuncname(char[] arg1);
    public A withNewFuncname(StringBuffer arg1);
    public A withNewFuncname(byte[] arg1,int arg2);
    public A withNewFuncname(byte[] arg1);
    public A withNewFuncname(char[] arg1,int arg2,int arg3);
    public A withNewFuncname(byte[] arg1,int arg2,int arg3);
    public A withNewFuncname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFuncname(String arg1);
    public String getParameters();
    public A withParameters(String parameters);
    public Boolean hasParameters();
    public A withNewParameters(StringBuilder arg1);
    public A withNewParameters(int[] arg1,int arg2,int arg3);
    public A withNewParameters(char[] arg1);
    public A withNewParameters(StringBuffer arg1);
    public A withNewParameters(byte[] arg1,int arg2);
    public A withNewParameters(byte[] arg1);
    public A withNewParameters(char[] arg1,int arg2,int arg3);
    public A withNewParameters(byte[] arg1,int arg2,int arg3);
    public A withNewParameters(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewParameters(String arg1);
    public String getPredicate();
    public A withPredicate(String predicate);
    public Boolean hasPredicate();
    public A withNewPredicate(StringBuilder arg1);
    public A withNewPredicate(int[] arg1,int arg2,int arg3);
    public A withNewPredicate(char[] arg1);
    public A withNewPredicate(StringBuffer arg1);
    public A withNewPredicate(byte[] arg1,int arg2);
    public A withNewPredicate(byte[] arg1);
    public A withNewPredicate(char[] arg1,int arg2,int arg3);
    public A withNewPredicate(byte[] arg1,int arg2,int arg3);
    public A withNewPredicate(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPredicate(String arg1);
}
